#include <cassert>
#include <cstdio>
#include <algorithm>
#include <vector>
#include <ctime>
using namespace std;
#define pb push_back
#define mp make_pair
#define fs first
#define sc second
#define sz(a) ((int) (a).size())
#define taskname "flashmob"

const int N = 4 * 123456 + 10;
const int inf = (int) 1e9 + 1;
int ansx[N], ansy[N], x[N][2], y[N][2], x_size[N], pos[N], n;
vector< pair< int, pair<int, int> > > x_events[N], y_events[N];
vector<int> allx, ally;

struct t_rmq {
	pair<int, int>* rmq;
	int n;
	t_rmq(int max_size = 0) {
		n = max_size;
		while (n & (n - 1))
			++n;
		if (n > 0) {
			rmq = new pair<int, int>[2 * n - 1];
			init(0, 0, n - 1);
		}
	}
	void init(int t, int l, int r) {
		if (l == r)
			rmq[t] = mp(-inf, l);
		else {
			int m = (l + r) / 2;
			init(t * 2 + 1, l, m);
			init(t * 2 + 2, m + 1, r);
			rmq[t] = max(rmq[t * 2 + 1], rmq[t * 2 + 2]);
		}
	}
	pair<int, int> get(int l, int r) {
		pair<int, int> res = mp(-inf, -1);
		l += n - 1, r += n - 1;
		while (l < r) {
			if (l % 2 == 0)
				res = max(res, rmq[l++]);
			if (r % 2 == 1)
				res = max(res, rmq[r--]);
			l = (l - 1) / 2, r = (r - 1) / 2;
		}
		return (l <= r) ? max(res, rmq[l]) : res;
	}
	void update(int t, int value) {
		t += n - 1;
		rmq[t] = mp(value, t - (n - 1));
		while (t > 0) {
			t = (t - 1) / 2;
			rmq[t] = max(rmq[t * 2 + 1], rmq[t * 2 + 2]);
		}
	}
};

struct t_set {
	t_rmq rmq;
	int n;
	t_set(int max_size = 0): rmq(max_size), n(0) {
	}
	~t_set() {}
	void insert(int x) {
		pos[x] = n++;
		rmq.update(pos[x], -x);
	}
	void erase(int x) {
		rmq.update(pos[x], -inf);
	}
	int get_min() {
		return -rmq.rmq[0].fs;
	}
};

t_rmq projection;
t_set current, state[N];

void try_to_find_answer(int i, int l, int r) {
	l = max(l, x[i][0]), r = min(r, x[i][1]);
	if ((ansx[i] == 0) && (ansy[i] == 0) && (l <= r)) {
		pair<int, int> tmp = projection.get(l, r);
		if (tmp.fs >= i) {
			ansx[i] = allx[tmp.sc];
			ansy[i] = ally[y[i][0]];
		}
	}
}

void solve() {
	current = t_set(n);
	projection = t_rmq(sz(allx));
	for (int i = 0; i < sz(allx); ++i) {
		x_events[i].clear();
		projection.update(i, inf);
		x_size[i] = 0;
	}
	for (int i = 0; i < sz(ally); ++i)
		y_events[i].clear();
	for (int i = 0; i < n; pos[i] = -1, ++i)
		if (x[i][0] == x[i][1]) {
			x_events[y[i][0]].pb(mp(x[i][0], mp(i, -1)));
			x_events[y[i][1] + 1].pb(mp(x[i][0], mp(i, 1)));
			x_size[x[i][0]]++;
		} else {
			y_events[y[i][0]].pb(mp(x[i][0], mp(i, -1)));
			y_events[y[i][0]].pb(mp(x[i][1] + 1, mp(i, 1)));
		}
	for (int i = 0; i < sz(allx); ++i)
		state[i] = t_set(x_size[i]);
	for (int i = 0; i < sz(ally); ++i) {
		for (int j = 0; j < sz(x_events[i]); ++j) {
			if (x_events[i][j].sc.sc == -1)
				state[x_events[i][j].fs].insert(x_events[i][j].sc.fs);
			else
				state[x_events[i][j].fs].erase(x_events[i][j].sc.fs);
			projection.update(x_events[i][j].fs, state[x_events[i][j].fs].get_min());
		}
		sort(y_events[i].begin(), y_events[i].end());
		for (int j = 0; j < sz(y_events[i]); ++j) {
			if (y_events[i][j].sc.sc == -1)
				current.insert(y_events[i][j].sc.fs);
			else
				current.erase(y_events[i][j].sc.fs);
			if (current.get_min() != inf)
				try_to_find_answer(current.get_min(), y_events[i][j].fs, y_events[i][j + 1].fs - 1);
		}
	}
}

void compress(int (&x)[N][2], int n, vector<int> &allx) {
	for (int i = 0; i < n; ++i)
		for (int t = 0; t < 2; ++t)
			for (int delta = 0; delta <= 1; ++delta)
				allx.pb(x[i][t] + delta);
	allx.pb(inf);
	sort(allx.begin(), allx.end());
	allx.resize(unique(allx.begin(), allx.end()) - allx.begin());
	for (int i = 0; i < n; ++i)
		for (int t = 0; t < 2; ++t)
			x[i][t] = lower_bound(allx.begin(), allx.end(), x[i][t]) - allx.begin();
}

int main() {
	assert(freopen(taskname".in", "r", stdin));
	assert(freopen(taskname".out", "w", stdout));
	scanf("%d", &n);
	for (int i = 0; i < n; ++i) {
		for (int t = 0; t < 2; ++t)
			scanf("%d%d", &x[i][t], &y[i][t]);
		sort(x[i], x[i] + 2);
		sort(y[i], y[i] + 2);
	}
	compress(x, n, allx);
	compress(y, n, ally);
	for (int t = 0; t < 2; ++t) {
		solve();
		swap(x, y);
		swap(ansx, ansy);
		swap(allx, ally);
	}
	for (int i = 0; i < n; ++i)
		if (ansx[i] == 0) {
			printf("0\n");
			return 0;
		}
	printf("%d\n", n);
	for (int i = 0; i < n; ++i)
		printf("%d %d\n", ansx[i], ansy[i]);
	return 0;
}