#include <iostream>
#include <cassert>
#include <cmath>
#include <string>
#include <cstring>
#include <vector>
#include <fstream>
#include <algorithm>
#include <cstdio>
#include <cstdlib>
#include <set>
#include <map>
#include <iomanip>
#define nextLine() { for (int c = getchar(); c != '\n' && c != EOF; c = getchar()); }
#define sqr(a) ((a)*(a))
#define has(mask,i) (((mask) & (1<<(i))) == 0 ? false : true)
#define eprintf(...) fprintf(stderr, __VA_ARGS__)
using namespace std;

#define pii pair<int,int>
#define mp make_pair
#define pb push_back
#define fi first
#define se second

#if ( _WIN32 || __WIN32__ )
    #define LLD "%I64d"
#else
    #define LLD "%lld"
#endif

typedef long long LL;
typedef long double ldb;
typedef vector <int> vi;
typedef vector <vi> vvi;
typedef vector <bool> vb;
typedef vector <vb> vvb;

const int INF = (1 << 30) - 1;
const ldb EPS = 1e-9;
const ldb PI = fabs(atan2(0.0, -1.0));
const int MAXN = 100100;
const int SQSIZE = 500;
const int BLOCKSIZE = (MAXN + SQSIZE - 1) / SQSIZE;

int n, t, k;

class Segment
{
public:
	int left;
	int right;

	Segment() {};

	Segment(int left, int right)
	{
		this->left = left;
		this->right = right;
	}

	int getShips() const
	{
		if (!good()) return 0;
		return (right - left + 2) / (k + 1);
	}

	int getPoints() const
	{
		int last = (right - left + 1) - k * getShips() - (getShips() - 1);
		return max(0, getShips() * (k - last));
	}	

	bool good() const
	{
		return left <= right;
	}
};

int T;
int blockColor[BLOCKSIZE];
int lastBlockChange[BLOCKSIZE];

int color[MAXN];
int lastChange[MAXN];

int sumShips;
int sumPoints;

vector <Segment> segments;

inline int getId(int x)
{
	int blockId = x / SQSIZE;
	return lastBlockChange[blockId] > lastChange[x] ? 
			blockColor[blockId] : color[x];
}

void add(int left, int right)
{
	if (left > right) return;
	int newColor = segments.size();
	T++;
	int startBlock = left / SQSIZE;
	for (int block = startBlock; block < BLOCKSIZE; block++)
	{
		int blockLeft = block * SQSIZE;
		int blockRight = blockLeft + SQSIZE - 1;
		if (blockLeft > right) break;
		if (blockRight < left) continue;
		int curLeft = max(blockLeft, left);
		int curRight = min(blockRight, right);

		if (curLeft == blockLeft && curRight == blockRight)
		{
			blockColor[block] = newColor;
			lastBlockChange[block] = T;
		}
		else
		{
			for (int i = curLeft; i <= curRight; i++)
			{
				lastChange[i] = T;
				color[i] = newColor;
			}
		}
	}
	segments.pb(Segment(left, right));
	sumShips += segments.back().getShips();
	sumPoints += segments.back().getPoints();
}

void solve()
{
	scanf("%d%d%d", &n, &t, &k);
	add(0, n - 1);
	printf("%d\n", sumShips == t ? sumPoints : 0);
	fflush(stdout);

	for (int shot; ;)
	{
		scanf("%d", &shot);
		--shot;
		int id = getId(shot);
		sumShips -= segments[id].getShips();
		sumPoints -= segments[id].getPoints();
		add(segments[id].left, shot - 1);
		add(shot + 1, segments[id].right);
		if (sumShips < t) break;
		printf("0 %d\n", sumShips == t ? sumPoints : 0);
		fflush(stdout);
	}
	printf("1\n");
	fflush(stdout);
}

int main()
{
	solve();
	return 0;
}
