#include <iostream>
#include <cassert>
#include <cmath>
#include <string>
#include <cstring>
#include <vector>
#include <fstream>
#include <algorithm>
#include <cstdio>
#include <cstdlib>
#include <set>
#include <map>
#include <iomanip>
#define nextLine() { for (int c = getchar(); c != '\n' && c != EOF; c = getchar()); }
#define sqr(a) ((a)*(a))
#define has(mask,i) (((mask) & (1<<(i))) == 0 ? false : true)
#define eprintf(...) fprintf(stderr, __VA_ARGS__)
using namespace std;

#define pii pair<int,int>
#define mp make_pair
#define pb push_back
#define fi first
#define se second

#if ( _WIN32 || __WIN32__ )
    #define LLD "%I64d"
#else
    #define LLD "%lld"
#endif

typedef long long LL;
typedef long double ldb;
typedef vector <int> vi;
typedef vector <vi> vvi;
typedef vector <bool> vb;
typedef vector <vb> vvb;

const int INF = (1 << 30) - 1;
const ldb EPS = 1e-9;
const ldb PI = fabs(atan2(0.0, -1.0));

int n, t, k;
int m;

class Segment
{
public:
	int left;
	int right;

	Segment() {};

	Segment(int left, int right)
	{
		this->left = left;
		this->right = right;
	}

	int getShips() const
	{
		if (!good()) return 0;
		return (right - left + 2) / (k + 1);
	}

	int getPoints() const
	{
		int last = (right - left + 1) - k * getShips() - (getShips() - 1);
		return max(0, getShips() * (k - last));
	}	

	bool good() const
	{
		return left <= right;
	}
};

inline bool operator < (const Segment &a, const Segment &b)
{
	return a.left < b.left;
}

int sumShips = 0;
int sumPoints = 0;
set <Segment> alive;

void recount(const Segment &segment, int shootX)
{
	assert(alive.find(segment) != alive.end());
	alive.erase(segment);

	sumShips -= segment.getShips();
	sumPoints -= segment.getPoints();

	Segment left(segment.left, shootX - 1);
	Segment right(shootX + 1, segment.right);

	if (left.good()) 
	{
		sumPoints += left.getPoints();
		sumShips += left.getShips();
		alive.insert(left);
	}	
	if (right.good()) 
	{
		sumPoints += right.getPoints();
		sumShips += right.getShips();
		alive.insert(right);
	}	
}

bool doShoot(int shootX)
{
	assert(!alive.empty());
	set <Segment>::iterator it = alive.upper_bound(Segment(shootX, shootX));
	assert(it != alive.begin());
	--it;
	assert(it->left <= shootX && shootX <= it->right);
	Segment segment = *it;
	recount(segment, shootX);
	return sumShips < t;
}

void solve()
{
	scanf("%d%d%d", &n, &t, &k);
	Segment temp(0, n - 1);
	alive.insert(temp);
	sumShips = temp.getShips();
	sumPoints = temp.getPoints();
	
	printf("%d\n", sumShips == t ? sumPoints : 0);
	fflush(stdout);
	for (int a; ;)
	{
		scanf("%d", &a);
		--a;
		if (doShoot(a))
		{
			puts("1");
			fflush(stdout);
			return;
		}
		printf("0 %d\n", sumShips == t ? sumPoints : 0);
		fflush(stdout);
	}
}

int main()
{
	solve();
	return 0;
}
